function [integral,CC_npunti]=CC3(n,f)
%---------------------------------------------------
% This function compute the integral of f on [-1,1]^3
% by the tensor product Clenshaw-Curtis formula
% inputs: n=number of pts in one direction; 
%         f=the integrand.
% outputs: integral= the value computed;
%          CC_npunti=n^3, the total number of points. 
% ---------------------------------------------------
% Authors: 
%      Stefano De Marchi
%      Department of Computer Science
%      University of Verona
%   
%      Marco Vianello
%      Department of Pure and Applied Math.
%      University of Padova
%      
% Version: May 2008
%------------------------------------------------------
% 1d Clenshaw-Curtis
[x,w]=fclencurt(n,-1,1); %x=nodes (1d array), 
                         %w=weights
                          
[X,Y,Z]=ndgrid(x);
[Wx,Wy,Wz]=ndgrid(w);
W=[Wx(:),Wy(:),Wz(:)];
WW=W(:,1).*W(:,2).*W(:,3);
FC=f(X,Y,Z);

FF=reshape(FC,n^3,1);
CC_npunti=n^3;
integral=WW'*FF;
return
