function [our_npunti,err_quad]=CXC_Cubature(n,Val_exact,fam)
%  This function allows to compute integrals
%  by a non-tensor Clenshaw-Curtis like formula  
%  for the Chebyshev measure in  the cube.
%
% inputs: n=degree
%         Val_exact=the exact value of the integral
%         fam=paramter that allows to choose one of  
%             the four sub-grids listed below
% 
% outputs: our_npoints=number of points used
%          err_quad=relative abs error 
% ----------------------------------------- 
%  Authors: 
%      Stefano De Marchi
%      Department of Computer Science
%      University of Verona
%   
%      Marco Vianello
%      Department of Pure and Applied Math.
%      University of Padova
%      
% Version: May 2008
% -----------------------------------------


c=cos([0:n]*pi/n);     % Chebsyhev points
[X,Y,Z]=ndgrid(c);     % 3d grid of Chebsyhev points in the cube
Sc=[X(:), Y(:), Z(:)]; % this is the Chebyshev grid arranged as an array with 3 coordinates

% Here we extract the sub-vector E=EVEN and O=ODD of the Chebsyhev points 
E=c(1:2:length(c));
O=c(2:2:length(c));

%----------------------------------------
% generation of the sub-grids 
%
% We have 4 possible choices
% 1) EEE OOO
% 2) EOO OEE
% 3) OEE EOO
% 4) EOE OEO
%----------------------------------------
switch(fam)
    case 1
[X1,Y1,Z1]=meshgrid(E,E,E);
[X2,Y2,Z2]=meshgrid(O,O,O);
    case 2
[X1,Y1,Z1]=meshgrid(E,E,O);
[X2,Y2,Z2]=meshgrid(O,O,E);

    case 3
[X1,Y1,Z1]=meshgrid(E,O,O);
[X2,Y2,Z2]=meshgrid(O,E,E);
    case 4
[X1,Y1,Z1]=meshgrid(O,O,O);
[X2,Y2,Z2]=meshgrid(E,E,E);
end

EEE=[X1(:),Y1(:),Z1(:)];
OOO=[X2(:),Y2(:),Z2(:)];
U=[EEE;OOO];
our_npunti=size(U,1);

[MU,IU]=setdiff(Sc,U,'rows'); % indices of the points of product Chebyshev-Lobatto grid
                              % which are not Xu points on the Cube
                              % Chebyshev-Lobatto che non sono di Xu sul cubo
    
% The function at the Xu points and zero elsewhere 
LSc=length(Sc(:,1));
f=zeros(LSc,1);
JU=setdiff(1:LSc,IU);
V=Sc(JU,:);  %punti di Xu in 3D
[f(JU),f_name]=fCube(V(:,1),V(:,2),V(:,3));
%ff=f;

%------------------------------------------
% compute the weights W, the structure F and
% integrals with
% - our formula
% - Tensor-product Gauss-Chebsyhev
% - Tensor-product Gauss-Chebsyhev-Lobatto
%-------------------------------------------

% our formula: OUR_integral is computed by the 
% function CX_weights (see its code)
[F,W,OUR_integral]= CX_weights(n,f,c,V,JU);
%------------------
%   Compute errors 
%-----------------
% Chebyshev measure: our formula
err_quad=abs(OUR_integral-Val_exact)/abs(Val_exact);




