%------------------------------------------
% Compute integrals with
% - our formula
% - Tensor-product Gauss-Chebsyhev
% - Tensor-product Gauss-Chebsyhev-Lobatto
%-------------------------------------------
%  Authors: 
%      Stefano De Marchi
%      Department of Computer Science
%      University of Verona
%   
%      Marco Vianello
%      Department of Pure and Applied Math.
%      University of Padova
%      
% Version: May 2008
% -----------------------------------------
clear all
close all

fam=input(' Which family of points = ');
nmin=2;
nmax=30;

[X,f_name]=fCube(1,2,3);   % just for getting the function name

Val_exact=GC3(120,@fCube); % We use as EXACT value of the integral the one
                           % obtained by the tensor product Gauss-Legendre
                           % of degree n=120.
                                    
for n=nmin:nmax+1,
  [GC_npunti(n-1),err_quad_GC(n-1),GCL_npunti(n-1),err_quad_GCL(n-1)]=CXC_Tens_Cubature(n,Val_exact);
end

nmax1=floor(4^(1/3)*nmax);
for n=nmin:nmax1+1,
    [our_npunti(n-1),err_quad(n-1)]=CXC_Cubature(n,Val_exact,fam);
end

%---------------
% Plots
%---------------
semilogy(our_npunti,err_quad,'r-o',GC_npunti,err_quad_GC,'r-*',GCL_npunti,err_quad_GCL,'b-^'); 
legend('Our formula','Tens.-prod. Gauss-Chebsyhev', 'Tens.-prod. Gauss-Chebyshev-Lobatto');
xlabel('Number of function evaluations')
str=['Cubature rel. errors for ',f_name]; 
title(str);
