% ----------------------------------------
%  M-file that allows to compute integrals
%  either using non-tensor Clenshaw-Curtis
%  or tensor-product Gauss-Legendre and
%  Gauss-Legendre_Lobatto cubature 
% -----------------------------------------
%  Authors: 
%      Stefano De Marchi
%      Department of Computer Science
%      University of Verona
%   
%      Marco Vianello
%      Department of Pure and Applied Math.
%      University of Padova
%      
% Version: May 2008
% -----------------------------------------
clear all
close all

fam=input(' Which family of points = ');
nmin=2;
nmax=20;

[X,f_name]=fCube(1,2,3);  % just for getting the function name

Val_exact=GL3(120,@fCube); % We use as EXACT value of the integral the one
                           % obtained by the tensor product Gauss-Legendre
                           % of degree n=120.
                           
         
for n=nmin:nmax+1,
  [GL_npunti(n-1),err_quad_GL(n-1), ....
   GLL_npunti(n-1),err_quad_GLL(n-1), ...
   CC_npunti(n-1),err_quad_CC(n-1)]=CX_Tens_Cubature(n,Val_exact);
end

nmax1=floor(4^(1/3)*nmax);
for n=nmin:nmax1+1,
    [our_npunti(n-1),err_quad(n-1)]=CX_Cubature(n,Val_exact,fam);
end

%---------------
% Plots
%---------------

semilogy(our_npunti,err_quad,'r-o',CC_npunti, err_quad_CC,'r-*',GL_npunti, err_quad_GL,'b-^', GLL_npunti, err_quad_GLL,'g-s'); 
legend('Non-tens. Clenshaw-Curtis','Tens.-prod. Clenshaw-Curtis', 'Tens.-prod. Gauss-Legendre', 'Tens.-prod. Gauss-Legendre-Lobatto');
xlabel('Number of function evaluations')
str=['Cubature rel errors for ', f_name]; 
title(str); 
